import React from 'react';
import { Table, Spinner, Alert } from 'react-bootstrap';

class MemberList extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
            members: [],
            isLoading: false,
            error: null
        };
    }

    componentDidMount() {
        this.setState({ isLoading: true });

        fetch('/api/member')
            .then(response => response.json())
            .then(members => this.setState({ members, isLoading: false }))
            .catch(error => this.setState({error, isLoading: false }));
    }

    render() {
        if (this.state.isLoading) {
            return <Spinner animation="border" />;
        }

        if (this.state.error != null) {
            return (
                <Alert variant="danger">
                   Ha ocurrido un error cargando el listado de socias: {this.state.error}
                </Alert>
            );
        }

        const entries = this.state.members.map((member) => {
            return (
                <tr key={member.num}>
                    <td>{member.num}</td>
                    <td>{member.name}</td>
                    <td>{member.email}</td>
                    <td>{(member.balance/100).toFixed(2)}</td>
                </tr>
            )
        });

        return (
            <Table striped bordered hover>
                <thead>
                    <tr>
                        <th>Numero</th>
                        <th>Nombre</th>
                        <th>Email</th>
                        <th>Saldo</th>
                    </tr>
                </thead>
                <tbody>
                    {entries}
                </tbody>
            </Table>
        );
    }
}

export default MemberList;
